%
% function reconstructed_frames = MC_CS_PL_Decoder_ForwardBackward( ...
%   y, Phis, num_rows, num_cols, recon_2d, recon_for_tele)
% 
%   This function performs consecutive reconstruction which starts from
%   the key frame of GOP which normally sampled at high subrate. 
%   In this way, reconstructed current frame will be reference frame for
%   the next frame. This function returns reconstructed frames by MC-CS-PL. 
%
%   See:
%     S. Mun and J. E. Fowler, "Motion-Compensated Compressed-Sensing 
%     Reconstruction for Dynamic MRI," IEEE International Conference on
%     Image Processing, 2013 
%
%   Originally written by SungKwang Mun, Mississippi State University
%

%
% MC-CS-PL: Motion-Compensated Compressed Sensing - Projected Landweber
% Copyright (C) 2013  James E. Fowler
% http://www.ece.mstate.edu/~fowler/BCSPL/
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%

function reconstructed_frames = MC_CS_PL_Decoder_ForwardBackward( ...
    y, Phis, num_rows, num_cols, recon_2d, recon_for_tele)

num_frames = length(y);
reconstructed_frames = cell(1,num_frames);
reconstructed_frames{1} = recon_for_tele{1};

for i = 2:num_frames
  % exclude current frame
  recon_2ds_without_current = ...
      {recon_for_tele{1:i-1} recon_for_tele{i+1:end}};
  reconstructed_frames{i} = ...
      MC_CS_PL_Decoder(reconstructed_frames{i-1}, recon_2d{i-1}, y{i}, ...
      Phis, num_rows, num_cols, recon_2ds_without_current);
  % update the current frame for the reconstruction set for telescopic search
  recon_for_tele = {recon_for_tele{1:i-1} reconstructed_frames{i} ...
      recon_for_tele{i+1:end}};
end
