%
% function r = PSNR(x1, x2)
%
%   This function returns the PSNR between images x1 and x2.
% 
%   See:
%     S. Mun and J. E. Fowler, "Motion-Compensated Compressed-Sensing 
%     Reconstruction for Dynamic MRI," IEEE International Conference on
%     Image Processing, 2013 
%
%   Originally written by SungKwang Mun, Mississippi State University
%

%
% MC-CS-PL: Motion-Compensated Compressed Sensing - Projected Landweber
% Copyright (C) 2013  James E. Fowler
% http://www.ece.mstate.edu/~fowler/BCSPL/
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%

function r = PSNR(x1, x2)

error = x1 - x2;

r = 10 * log10(255^2 / mean(error(:).^2));
