%
% function [M,Mh,mi,mhi] = random_radial_line_mask(L,num_rows)
%
% This function generates radial sensing mask with randomly specified  
% used in 2D Fourier domain. L is number of radial lines, and N is number of
% rows or columns of the image.
% This function returns whole sized mask, half sized mask, index of the whole 
% sized mask, and index of the half sized
%
% Originally Written by : Justin Romberg
% Modified by SungKwang Mun, Mississippi State University
%

%
% MC-CS-PL: Motion-Compensated Compressed Sensing - Projected Landweber
% Copyright (C) 2013  James E. Fowler
% http://www.ece.mstate.edu/~fowler/BCSPL/
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%

function [M,Mh,mi,mhi] = random_radial_line_mask(L,num_rows)

offset = rand(1)*(pi/L);
thc = linspace(offset, pi-pi/L + offset, L);

M = zeros(num_rows);
% full mask
for i = 1:L
  
  if ((thc(i) <= pi/4) || (thc(i) > 3*pi/4))
    yr = round(tan(thc(i))*(-num_rows/2+1:num_rows/2-1))+num_rows/2+1;
    for nn = 1:num_rows-1
      M(yr(nn),nn+1) = 1;
    end
  else 
    xc = round(cot(thc(i))*(-num_rows/2+1:num_rows/2-1))+num_rows/2+1;
    for nn = 1:num_rows-1
      M(nn+1,xc(nn)) = 1;
    end
  end
  
end

% upper half plane mask (not including origin)
% Mh = zeros(num_rows);
Mh = M;
Mh(num_rows/2+2:num_rows,:) = 0;
Mh(num_rows/2+1,num_rows/2+1:num_rows) = 0;


% M = ifftshift(M);
mi = find(M);
Mh = ifftshift(Mh);
mhi = find(Mh);
