% 
% function run_cspl_ddwt()
% 
%   This function runs the experiments for CS-PL (DDWT) in Figure 1 of
%     S. Mun and J. E. Fowler, "Motion-Compensated Compressed-Sensing
%     Reconstruction for Dynamic MRI," submitted to the IEEE
%     International Conference on Image Processing, 2013
%
%   The DDWT transform used for reconstruction has num_levels
%   decompositions levels and is implemented using the cplxdual2D
%   program from the Wavelet Software package from
%   http://taco.poly.edu/WaveletSoftware/.
%
%   Originally written by SungKwang Mun, Mississippi State University
%

%
% MC-CS-PL: Motion-Compensated Compressed Sensing - Projected Landweber
% Copyright (C) 2013  James E. Fowler
% http://www.ece.mstate.edu/~fowler/BCSPL/
% 
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%

function run_cspl_ddwt(y)

addpath(genpath('Data'));
addpath('../WaveletSoftware');

filename = 'brain_sagittal';
% subrates= 0.1:0.1:0.5;
subrates = 0.17;
num_trials = 5;
% additional regularization criterion,
% nonNegative = 1 enforces positiveness during the recovery
nonNegative = 1;  
num_levels = 5;

original_filename = [filename '.pgm'];
original_image = double(imread(original_filename));

[num_rows, num_cols] = size(original_image);

if num_rows ~= num_cols
  error('Image must be square');
end

% im_mean = mean(original_image(:));
im_mean = 0;
x = original_image - im_mean;

N = num_rows*num_cols;

for i = 1:length(subrates);
  subrate = subrates(i);
  
  % to determine how many radial lines are needed w.r.t subrate 
  L = round((0.6464*subrate^2 + 0.8431*subrate + 0.014)*num_rows);
  
  for j = 1:num_trials
    randn('seed',j);
    rand('seed',j);
    mask = random_radial_line_mask(L,num_rows);
    
    Phi = @(x) 1/sqrt(N)*fftshift(fft2(x)).*mask;
    Phi_t=  @(x) sqrt(N)*ifft2(ifftshift(x));
    
    y=Phi(x);
    
    tic
    reconstructed_image = CS_PL_DDWT_Decoder(y, Phi, Phi_t, num_rows, ...
        num_cols, nonNegative, num_levels);
    toc
    
    reconstructed_image = reconstructed_image + im_mean;
    psnrs(j,i) = PSNR(original_image, reconstructed_image)
  end
end
mean_psnrs = mean(psnrs,1)
imwrite(uint8(reconstructed_image), ... 
    [filename '_csspl_ddwt_radial.' num2str(subrates) '.pgm'])
