%
% function run_tv()
%
%   This function runs the experiment for TV in Figure 1 of
%     S. Mun and J. E. Fowler, "Motion-Compensated Compressed-Sensing 
%     Reconstruction for Dynamic MRI," IEEE International Conference on
%     Image Processing, 2013 
%
%   Test is performed using the tveq_logbarrier function
%   from the l1-magic Software package from
%   http://users.ece.gatech.edu/~justin/l1magic/
%
%   Originally written by SungKwang Mun, Mississippi State University
%

%
% MC-CS-PL: Motion-Compensated Compressed Sensing - Projected Landweber
% Copyright (C) 2013  James E. Fowler
% http://www.ece.mstate.edu/~fowler/BCSPL/
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; either version 2
% of the License, or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
%

function run_tv()

addpath(genpath('Data'));
addpath(genpath('../l1magic'));

filename = 'brain_sagittal';
% subrates= 0.1:0.1:0.5;
subrates = 0.17;
num_trials = 5;

original_filename = [filename '.pgm'];
original_image = double(imread(original_filename));
[num_rows, num_cols] = size(original_image);

% im_mean = mean(original_image(:));
im_mean = 0;
x = original_image - im_mean;

N = num_rows*num_cols;

for i = 1:length(subrates);
  subrate = subrates(i);
  
  % to determine how many radial lines are needed w.r.t subrate
  L = round((0.6464*subrate^2 + 0.8431*subrate + 0.014)*num_rows);
  
  for j = 1:num_trials
    randn('seed',j);
    rand('seed',j);
    [M Mh mi mhi] = random_radial_line_mask(L,num_rows);
    OMEGA = mhi;
    
    Phi = @(z) A_fhp(z, OMEGA);
    Phi_t = @(z) At_fhp(z, OMEGA, num_cols);
    
    
    y=Phi(x(:));
    
    % min l2 reconstruction (backprojection)
    xbp = Phi_t(y);
    % recovery
    tic
    xp = tveq_logbarrier(xbp, Phi, Phi_t, y, 1e-3, 10, 1e-8, 200);
    reconstructed_image = reshape(xp, num_rows, num_cols);
    toc
    
    reconstructed_image = reconstructed_image + im_mean;
    psnrs(j,i) = PSNR(original_image, reconstructed_image)
  end
end
mean_psnrs = mean(psnrs,1);
imwrite(uint8(reconstructed_image), ...
    [filename '_tv_radial.' num2str(subrates) '.pgm'])
